@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR;
 
-our $DATE = '2015-10-22'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-10-23'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 our @Module_Lists = (
     {
@@ -24,7 +24,7 @@ speed improvement if you run it against a local CPAN mirror like MiniCPAN
 though). Wouldn't mind faster version of stuffs :-)
 
 _
-                rating => 5,
+                rating => 10,
             },
         ],
     },
@@ -69,7 +69,7 @@ now `Log::Any::IfLOG` is a simple wrapper that avoids loading `Log::Any` unless
 some environment variable indicates that user wants logging.
 
 _
-                alternate_module => 'Log::Any::IfLOG',
+                alternate_modules => ['Log::Any::IfLOG'],
             },
             {
                 module => 'File::Flock',
@@ -82,12 +82,12 @@ al, all of which seem unnecessary. Nowadays I'm opting to use
 File::Flock::Retry, or just plain `flock()`.
 
 _
-                alternate_module => 'File::Flock::Retry',
+                alternate_modules => ['File::Flock::Retry'],
             },
             {
                 module => 'File::Slurp',
                 summary => 'Buggy',
-                alternate_module => 'File::Slurper',
+                alternate_modules => ['File::Slurper'],
             },
         ],
     },
@@ -135,15 +135,13 @@ Acme::CPANLists::PERLANCAR - PERLANCAR's CPAN lists
 
 =head1 VERSION
 
-This document describes version 0.04 of Acme::CPANLists::PERLANCAR (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2015-10-22.
+This document describes version 0.05 of Acme::CPANLists::PERLANCAR (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2015-10-23.
 
 =head1 DESCRIPTION
 
-This distribution is an experiment for providing data that can be used by
-L<https://cpanlists.org> (when I finally get around to finishing the project),
-L<lcpan> (when I implement indexing of module source codes), as well as
-L<http://cpanratings.perl.org> (as I'm currently having trouble logging in to
-the site).
+=head1 SEE ALSO
+
+L<Acme::CPANLists>
 
 =head1 HOMEPAGE
 
